MatchMakerMonitoring.prefix\_element\_names
===============================================================

.. currentmodule:: alfred3_interact.page

.. autoattribute:: MatchMakerMonitoring.prefix_element_names
